@@ -1,12 +1,19 @@
 package Catmandu::XLS;
 
+our $VERSION = '0.06';
+
 =head1 NAME
 
 Catmandu::XLS - modules for working with Excel .xls and .xlsx files
 
-=cut
+=begin markdown
 
-our $VERSION = '0.05';
+[![Build Status](https://travis-ci.org/LibreCat/Catmandu-XLS.png)](https://travis-ci.org/LibreCat/Catmandu-XLS)
+[![Coverage Status](https://coveralls.io/repos/LibreCat/Catmandu-XLS/badge.png?branch=devel)](https://coveralls.io/r/LibreCat/Catmandu-XLS?branch=devel)
+[![Kwalitee Score](http://cpants.cpanauthors.org/dist/Catmandu-XLS.png)](http://cpants.cpanauthors.org/dist/Catmandu-XLS)
+[![CPAN version](https://badge.fury.io/pl/Catmandu-XLS.png)](http://badge.fury.io/pl/Catmandu-XLS)
+
+=end markdown
 
 =head1 SYNPOSIS
 
@@ -63,4 +70,6 @@ This software is copyright (c) 2013 by Nicolas Steenlant.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=cut
+
 1;
